@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: add a travis status button to the README.md file
-our $VERSION = '1.90'; # VERSION
+our $VERSION = '1.91'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterBuild';
@@ -13,6 +13,11 @@ has travis_status => (
   is => 'ro',
 );
 
+has travis_user => (
+  is      => 'ro',
+  default => 'plicease',
+);
+
 sub after_build
 {
   my($self) = @_;
@@ -20,7 +25,8 @@ sub after_build
   if(-r $readme)
   {
     my $name = $self->zilla->root->absolute->basename;
-    my $status = $self->travis_status ? " [![Build Status](https://secure.travis-ci.org/plicease/$name.png)](http://travis-ci.org/plicease/$name)" : "";
+    my $user = $self->travis_user;
+    my $status = $self->travis_status ? " [![Build Status](https://secure.travis-ci.org/$user/$name.png)](http://travis-ci.org/$user/$name)" : "";
     my $content = $readme->slurp;
     $content =~ s{# NAME\s+(.*?) - (.*?#)}{# $1$status\n\n$2}s;
     $content =~ s{# VERSION\s+version (\d+\.|)\d+\.\d+(\\_\d+|)\s+#}{#};
@@ -48,7 +54,7 @@ Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup - add a travis status but
 
 =head1 VERSION
 
-version 1.90
+version 1.91
 
 =head1 SYNOPSIS
 
